==> libopenmpt-0.4.52+release.doc.tar.gz: libopenmpt-0.4.52+release.doc/docs/navtreedata.js <==
var NAVTREE =
[
  [ "libopenmpt", "index.html", [
    [ "Contents", "index.html", [
      [ "Contents", "index.html#toc", [
        [ "APIs", "index.html#toc_apis", null ]
      ] ],
      [ "Website", "index.html#toc_website", null ],
      [ "License", "index.html#toc_license", null ]
    ] ],
    [ "Quick Start", "quickstart.html", null ],
    [ "README", "md_README.html", null ],
    [ "Dependencies", "dependencies.html", null ],
    [ "Packaging", "packaging.html", null ],
    [ "Contributing", "md_doc_contributing.html", null ],
    [ "Coding conventions", "md_doc_libopenmpt_styleguide.html", null ],
    [ "Tests", "tests.html", null ],
    [ "Changelog", "changelog.html", null ],
    [ "TODO", "todo.html", null ],
    [ "How to add support for new module formats", "md_doc_module_formats.html", null ],
    [ "C++ API", "libopenmpt_cpp_overview.html", [
      [ "Error Handling", "libopenmpt_cpp_overview.html#libopenmpt_cpp_error", null ],
      [ "Strings", "libopenmpt_cpp_overview.html#libopenmpt_cpp_strings", null ],
      [ "File I/O", "libopenmpt_cpp_overview.html#libopenmpt_cpp_fileio", null ],
      [ "Output Format", "libopenmpt_cpp_overview.html#libopenmpt_cpp_outputformat", null ],
      [ "libopenmpt in multi-threaded environments", "libopenmpt_cpp_overview.html#libopenmpt_cpp_threads", null ],
      [ "Windows support", "libopenmpt_cpp_overview.html#libopenmpt-cpp-windows", null ],
      [ "Detailed documentation", "libopenmpt_cpp_overview.html#libopenmpt-cpp-detailed", null ],
      [ "Example", "libopenmpt_cpp_overview.html#libopenmpt_cpp_examples", null ]
    ] ],
    [ "C API", "libopenmpt_c_overview.html", [
      [ "Error Handling", "libopenmpt_c_overview.html#libopenmpt_c_error", null ],
      [ "Strings", "libopenmpt_c_overview.html#libopenmpt_c_strings", null ],
      [ "File I/O", "libopenmpt_c_overview.html#libopenmpt_c_fileio", null ],
      [ "Output Format", "libopenmpt_c_overview.html#libopenmpt_c_outputformat", null ],
      [ "libopenmpt in multi-threaded environments", "libopenmpt_c_overview.html#libopenmpt_c_threads", null ],
      [ "Statically linking to libopenmpt", "libopenmpt_c_overview.html#libopenmpt_c_staticlinking", null ],
      [ "Detailed documentation", "libopenmpt_c_overview.html#libopenmpt_c_detailed", null ],
      [ "Examples", "libopenmpt_c_overview.html#libopenmpt_c_examples", [
        [ "Unsafe, simplified example without any error checking to get a first idea of the API", "libopenmpt_c_overview.html#libopenmpt_c_example_unsafe", null ],
        [ "FILE*", "libopenmpt_c_overview.html#libopenmpt_c_example_file", null ],
        [ "in memory", "libopenmpt_c_overview.html#libopenmpt_c_example_inmemory", null ],
        [ "reading FILE* and writing PCM data to STDOUT (usable without PortAudio)", "libopenmpt_c_overview.html#libopenmpt_c_example_stdout", null ]
      ] ]
    ] ],
    [ "libopenmpt_ext C++ API", "libopenmpt_ext_cpp_overview.html", [
      [ "Detailed documentation", "libopenmpt_ext_cpp_overview.html#libopenmpt-ext-cpp-detailed", null ]
    ] ],
    [ "libopenmpt_ext C API", "libopenmpt_ext_c_overview.html", [
      [ "Detailed documentation", "libopenmpt_ext_c_overview.html#libopenmpt-ext-c-detailed", null ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", null, [
      [ "Namespace List", "namespaces.html", "namespaces" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Functions", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", null, [
      [ "File List", "files.html", "files" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", null ],
        [ "Functions", "globals_func.html", null ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__libopenmpt__c.html#ga487b51694e4cf74a9727baf802380b53",
"group__libopenmpt__ext__c.html#ga737466596e917bd196c7b30496aad1b8"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> libopenmpt-0.5.40+release.doc.tar.gz: libopenmpt-0.5.40+release.doc/docs/navtreedata.js <==
var NAVTREE =
[
  [ "libopenmpt", "index.html", [
    [ "Contents", "index.html", [
      [ "Contents", "index.html#toc", [
        [ "APIs", "index.html#toc_apis", null ]
      ] ],
      [ "Website", "index.html#toc_website", null ],
      [ "License", "index.html#toc_license", null ]
    ] ],
    [ "Quick Start", "quickstart.html", null ],
    [ "README", "md_README.html", null ],
    [ "Dependencies", "dependencies.html", null ],
    [ "Packaging", "packaging.html", null ],
    [ "Contributing", "md_doc_contributing.html", null ],
    [ "Coding conventions", "md_doc_libopenmpt_styleguide.html", null ],
    [ "Tests", "tests.html", null ],
    [ "Changelog", "changelog.html", null ],
    [ "TODO", "todo.html", null ],
    [ "How to add support for new module formats", "md_doc_module_formats.html", null ],
    [ "C++ API", "libopenmpt_cpp_overview.html", [
      [ "Error Handling", "libopenmpt_cpp_overview.html#libopenmpt_cpp_error", null ],
      [ "Strings", "libopenmpt_cpp_overview.html#libopenmpt_cpp_strings", null ],
      [ "File I/O", "libopenmpt_cpp_overview.html#libopenmpt_cpp_fileio", null ],
      [ "Output Format", "libopenmpt_cpp_overview.html#libopenmpt_cpp_outputformat", null ],
      [ "libopenmpt in multi-threaded environments", "libopenmpt_cpp_overview.html#libopenmpt_cpp_threads", null ],
      [ "Windows support", "libopenmpt_cpp_overview.html#libopenmpt-cpp-windows", null ],
      [ "Detailed documentation", "libopenmpt_cpp_overview.html#libopenmpt-cpp-detailed", null ],
      [ "Example", "libopenmpt_cpp_overview.html#libopenmpt_cpp_examples", null ]
    ] ],
    [ "C API", "libopenmpt_c_overview.html", [
      [ "Error Handling", "libopenmpt_c_overview.html#libopenmpt_c_error", null ],
      [ "Strings", "libopenmpt_c_overview.html#libopenmpt_c_strings", null ],
      [ "File I/O", "libopenmpt_c_overview.html#libopenmpt_c_fileio", null ],
      [ "Output Format", "libopenmpt_c_overview.html#libopenmpt_c_outputformat", null ],
      [ "libopenmpt in multi-threaded environments", "libopenmpt_c_overview.html#libopenmpt_c_threads", null ],
      [ "Statically linking to libopenmpt", "libopenmpt_c_overview.html#libopenmpt_c_staticlinking", null ],
      [ "Detailed documentation", "libopenmpt_c_overview.html#libopenmpt_c_detailed", null ],
      [ "Examples", "libopenmpt_c_overview.html#libopenmpt_c_examples", [
        [ "Unsafe, simplified example without any error checking to get a first idea of the API", "libopenmpt_c_overview.html#libopenmpt_c_example_unsafe", null ],
        [ "FILE*", "libopenmpt_c_overview.html#libopenmpt_c_example_file", null ],
        [ "in memory", "libopenmpt_c_overview.html#libopenmpt_c_example_inmemory", null ],
        [ "reading FILE* and writing PCM data to STDOUT (usable without PortAudio)", "libopenmpt_c_overview.html#libopenmpt_c_example_stdout", null ]
      ] ]
    ] ],
    [ "libopenmpt_ext C++ API", "libopenmpt_ext_cpp_overview.html", [
      [ "Detailed documentation", "libopenmpt_ext_cpp_overview.html#libopenmpt-ext-cpp-detailed", null ]
    ] ],
    [ "libopenmpt_ext C API", "libopenmpt_ext_c_overview.html", [
      [ "Detailed documentation", "libopenmpt_ext_c_overview.html#libopenmpt-ext-c-detailed", null ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", null, [
      [ "Namespace List", "namespaces.html", "namespaces" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Functions", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", null, [
      [ "File List", "files.html", "files" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", null ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__libopenmpt__c.html#ga3d83925bb2083e25515a79a48321a4ce",
"group__libopenmpt__c.html#gaff878452d42b028d3c764794524f07cc"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
